@@ -51,6 +51,7 @@ cb_copy_in_user_format_menuitem_activate (GtkWidget *menuitem, KzTabLabel *kztab
 	gchar *format;
 	gchar *text;
 	gchar *str;
+	gchar *compress_str;
 	gint i;
 	gint counts = 0;
 
@@ -141,9 +142,12 @@ cb_copy_in_user_format_menuitem_activate (GtkWidget *menuitem, KzTabLabel *kztab
 
 	g_free(format);
 
-	gtkutil_copy_text(str);
+	compress_str = g_strcompress(str);
+
+	gtkutil_copy_text(compress_str);
 
 	if(str) g_free(str);
+	if(compress_str) g_free(compress_str);
 	if(text) g_free(text);
 }
 
