@@ -574,6 +574,18 @@ act_view_source (GtkAction *action, KzWindow *kz)
 	}
 }
 
+static void 
+act_show_page_certificate (GtkAction *action, KzWindow *kz)
+{
+	GtkWidget *widget = KZ_WINDOW_CURRENT_PAGE(kz);
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+
+	if (KZ_IS_EMBED(widget))
+	{
+		kz_embed_show_page_certificate(KZ_EMBED(widget));
+	}
+}
+
 #if 0
 static void 
 act_set_edit_mode (GtkAction *action, KzWindow *kz)
@@ -964,7 +976,7 @@ act_tab_close_forward_all (GtkAction *action, KzWindow *kz)
 
 
 static void
-act_tab_close_all_without_active (GtkAction *action, KzWindow *kz)
+act_tab_close_all_inactive_active (GtkAction *action, KzWindow *kz)
 {
 	gint i, pos, num;
 
@@ -1464,23 +1476,30 @@ act_restore_session (GtkAction *action, KzWindow *kz)
 		{
 			GtkWidget *widget;
 			KzBookmark *child = KZ_BOOKMARK(tabnode->data);
-
+			KzTabLabel *kztab;
 			widget = kz_window_open_new_tab_at_tail(window, NULL);
 			kz_embed_set_history(KZ_EMBED(widget), child);
+			kztab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(GTK_NOTEBOOK(window->notebook),
+									widget));
+
 			if (kz_bookmark_get_lock(child))
 			{
-				KzTabLabel *kztab;
-				kztab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(GTK_NOTEBOOK(window->notebook),
-										widget));
 				kz_tab_label_set_lock(kztab, TRUE);
 			}
 			if (kz_bookmark_get_auto_refresh(child))
 			{
-				KzTabLabel *kztab;
-				kztab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(GTK_NOTEBOOK(window->notebook),
-										widget));
 				kz_tab_label_set_auto_refresh(kztab, TRUE);
 			}
+			if (kz_bookmark_get_javascript(child))
+			{
+				kz_embed_set_allow_javascript(KZ_EMBED(kztab->kzembed), TRUE);
+				kz_tab_label_set_javascript(kztab, TRUE);
+			}
+			else
+			{
+				kz_embed_set_allow_javascript(KZ_EMBED(kztab->kzembed), FALSE);
+				kz_tab_label_set_javascript(kztab, FALSE);
+			}
 		}
 		g_list_free(tabs);
 		pos = kz_bookmark_get_current(window_bookmark);
@@ -1818,9 +1837,20 @@ act_show_hide_sidebar (GtkAction *action, KzWindow *kz)
 
 	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action));
 	if (active)
+	{
+		if (!kz_paned_is_showing_all_children(KZ_PANED(kz->pane)))
+		{
+			gint width;
+			gtk_widget_get_size_request(kz->sidebar, &width, NULL);
+			kz_paned_set_separator_position(KZ_PANED(kz->pane),
+							MAX(1, width));
+		}
 		gtk_widget_show(kz->sidebar);
+	}
 	else
+	{
 		gtk_widget_hide(kz->sidebar);
+	}
 
 	KZ_WINDOW_SET_VISIBLE(kz, "StockSidebarPosMenu", active);
 }
@@ -1921,7 +1951,7 @@ GtkActionEntry kz_actions[] =
   {"OpenSelectedText",         NULL,           N_("Open selected text"),     NULL,     N_("Open URIs extracted from selected text "), G_CALLBACK(act_open_selected_text)},
   {"Open",              GTK_STOCK_OPEN,     N_("_Open File..."),       CTRL"O",  N_("Open a local file"), G_CALLBACK(act_open_file)},
 
-  {"OpenSelectedLinks", KZ_STOCK_OPEN_SELECTED_LINK, N_("Open selected links"), CTRL"G",  N_("Open slected links"), G_CALLBACK(act_open_selected_links)},
+  {"OpenSelectedLinks", KZ_STOCK_OPEN_SELECTED_LINK, N_("Open selected links"), CTRL"G",  N_("Open selected links"), G_CALLBACK(act_open_selected_links)},
 
   {"CloseWindow",    KZ_STOCK_CLOSE_WINDOW, N_("_Close Window"),       CTRL"Q",  N_("Close the current window"), G_CALLBACK(act_close_window)},
   {"CloseTab",          GTK_STOCK_CLOSE,    N_("Close Ta_b"),          CTRL"W",  N_("Close the current tab"), G_CALLBACK(act_close_tab)},
@@ -1972,6 +2002,7 @@ GtkActionEntry kz_actions[] =
   {"ZoomOut",   GTK_STOCK_ZOOM_OUT, N_("Zoom out"),    NULL, N_("Zoom out this page"),  G_CALLBACK(act_zoom_out)},
 
   {"ViewPageSource", KZ_STOCK_VIEW_SOURCE, N_("View page source"), NULL, N_("View the source code of the page"), G_CALLBACK(act_view_source)},
+  {"ShowPageCertificate", NULL, N_("Show page certificate"), NULL, N_("Show the certificate of the page"), G_CALLBACK(act_show_page_certificate)},
   {"AutoScrollMode", NULL,          N_("Autoscroll mode"), NULL, N_("set auto-scroll mode"), G_CALLBACK(act_auto_scroll_mode)},
   {"ThumbnailTabList", NULL,          N_("ThumbnailTabList"), NULL, N_("Display the tab list with thumbnail"), G_CALLBACK(act_thumbnail_tablist)},
 /*
@@ -1992,7 +2023,7 @@ GtkActionEntry kz_actions[] =
 
   {"CloseAllBackwardTab", KZ_STOCK_CLOSE_BACKWARD, N_("Close all _backward tabs"), NULL, NULL, G_CALLBACK(act_tab_close_backward_all)},
   {"CloseAllForwardTab", KZ_STOCK_CLOSE_FORWARD, N_("Close all _forward tabs"),  NULL, NULL, G_CALLBACK(act_tab_close_forward_all)},
-  {"CloseAllTabWithoutActive", NULL, N_("Close all tabs without _active"), NULL, NULL, G_CALLBACK(act_tab_close_all_without_active)},
+  {"CloseAllInactiveTabs", NULL, N_("Close all _inactive tabs"), NULL, NULL, G_CALLBACK(act_tab_close_all_inactive_active)},
 
   {"OpenBookmarkInNewTab",      NULL, N_("Open the bookmark in new _tab"),   NULL,  NULL, G_CALLBACK(act_bookmark_in_new_tab)},
   {"OpenAllBookmarks",          NULL, N_("Open a_ll bookmarks"),             NULL,  NULL, G_CALLBACK(act_open_all_bookmarks)},
@@ -2278,12 +2309,13 @@ kz_actions_set_tab_sensitive (KzWindow *kz, KzEmbed *kzembed)
 			combine_favicon(action,	uri, kz);
 			KZ_WINDOW_SET_SENSITIVE(kz, "CloseAllForwardTab", TRUE);
 		}
+		KZ_WINDOW_SET_SENSITIVE(kz, "CloseAllInactiveTabs", TRUE);
 	}
 	else
 	{
-		KZ_WINDOW_SET_SENSITIVE(kz, "CloseAllBackwardTab",      FALSE);
-		KZ_WINDOW_SET_SENSITIVE(kz, "CloseAllForwardTab",       FALSE);
-		KZ_WINDOW_SET_SENSITIVE(kz, "CloseAllTabWithoutActive", FALSE);
+		KZ_WINDOW_SET_SENSITIVE(kz, "CloseAllBackwardTab",  FALSE);
+		KZ_WINDOW_SET_SENSITIVE(kz, "CloseAllForwardTab",   FALSE);
+		KZ_WINDOW_SET_SENSITIVE(kz, "CloseAllInactiveTabs", FALSE);
 	}
 
 	if (kzembed && kz_embed_get_nav_link(kzembed, KZ_EMBED_LINK_RSS))
