@@ -22,8 +22,6 @@
 #define __KZ_FAVICON_H__
 
 #include <gtk/gtk.h>
-#include "kz-icons.h"
-#include "kz-embed.h"
 
 G_BEGIN_DECLS
 
