@@ -80,6 +80,12 @@
 #include "utils.h"
 #include "MozillaPrivate.h"
 
+# include <nsISSLStatus.h>
+# include <nsISSLStatusProvider.h>
+# include <nsICertificateDialogs.h>
+# include <nsIX509Cert.h>
+# include <nsISecureBrowserUI.h>
+
 #ifdef HAVE_CONFIG_H
 #	include "config.h"
 #endif /* HAVE_CONFIG_H */
@@ -158,6 +164,31 @@ KzMozWrapper::Init (KzMozEmbed *kzembed)
 
 	if (NS_FAILED (rv)) g_warning("failed to add a history listener");
 #endif
+
+// SSL related code
+// These codes are picked from mozilla/GaleonWrapper in Galeon 1.3.21.
+// Original copyright notice.
+// Copyright (C) 2000 Marco Pesenti Gritti
+
+#ifdef HAVE_NSIDOCSHELL_GETSECUREUI
+	nsCOMPtr<nsIDocShell> docShell (do_GetInterface (mWebBrowser, &rv));
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	rv = docShell->GetSecurityUI (getter_AddRefs (mSecurityInfo));
+	NS_ENSURE_SUCCESS (rv, rv);
+#else
+	// Workaround for http://bugzilla.gnome.org/show_bug.cgi?id=164670
+	mSecurityInfo = do_CreateInstance("@kazehakase.sf.jp/hacks/secure-browser-ui;1");
+	if (mSecurityInfo)
+	{
+		mSecurityInfo->Init (mDOMWindow);
+	}
+	else
+	{
+		g_warning ("Failed to instantiate nsISecureBrowserUI!\n");
+	}
+#endif
+
 	return NS_OK;
 }
 
@@ -1906,3 +1937,42 @@ KzMozWrapper::SetAllowImages (PRBool aAllow)
 	return DocShell->SetAllowImages(aAllow);
 }
 
+
+// SSL related code
+// These codes are picked from mozilla/GaleonWrapper in Galeon 1.3.21.
+// Original copyright notice.
+// Copyright (C) 2000 Marco Pesenti Gritti
+nsresult
+KzMozWrapper::GetSSLStatus (nsISSLStatus **aSSLStatus)
+{
+	NS_ENSURE_TRUE (mSecurityInfo, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsISSLStatusProvider> sp = do_QueryInterface (mSecurityInfo);
+	NS_ENSURE_TRUE (sp, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsISSLStatus> SSLStatus;
+	sp->GetSSLStatus(getter_AddRefs(SSLStatus));
+	NS_ENSURE_TRUE (SSLStatus, NS_ERROR_FAILURE);
+
+	NS_ADDREF(*aSSLStatus = SSLStatus);
+	return NS_OK;
+}
+
+nsresult
+KzMozWrapper::ShowPageCertificate (void)
+{
+	nsresult rv;
+	nsCOMPtr<nsISSLStatus> SSLStatus;
+	GetSSLStatus (getter_AddRefs(SSLStatus));
+	NS_ENSURE_TRUE (SSLStatus, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIX509Cert> serverCert;
+	SSLStatus->GetServerCert (getter_AddRefs (serverCert));
+	NS_ENSURE_TRUE (serverCert, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsICertificateDialogs> certDialogs =
+		do_GetService (NS_CERTIFICATEDIALOGS_CONTRACTID, &rv);
+	NS_ENSURE_TRUE (certDialogs, NS_ERROR_FAILURE);
+
+	return certDialogs->ViewCert (NULL, serverCert);
+}
