@@ -19,6 +19,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif /* HAVE_CONFIG_H */
+
 #include <stdio.h>
 #include <string.h>
 #include <glib/gi18n.h>
@@ -126,6 +130,7 @@ static GObjectClass *parent_class = NULL;
 static gint kz_io_signals[IO_LAST_SIGNAL] = {0};
 
 static GQuark error_quark     = 0;
+
 /* static GQuark redirect_quark  = 0; */
 
 KZ_OBJECT_GET_TYPE(kz_io, "KzIO", KzIO,
@@ -354,11 +359,12 @@ kz_io_new (const gchar *uri)
 	{
 		io = KZ_IO(kz_http_new(uri));
 	}
+#ifdef USE_SSL
 	else if (g_str_has_prefix(uri, "https://"))
 	{
-		/* io = KZ_IO(kz_https_new(uri)); */
+		io = KZ_IO(kz_http_new(uri));
 	}
-	
+#endif
 	else if (g_str_has_prefix(uri, "ftp://"))
 	{
 		/* io = KZ_IO(kz_ftp_new(uri)); */
@@ -475,7 +481,9 @@ cb_io_in(GIOChannel *iochannel, GIOCondition condition,
 	 case G_IO_STATUS_EOF:
 		{
 			if(priv->localfile)
+			{
 				g_io_channel_flush(priv->localfileio, NULL);
+			}
 			g_signal_emit(io,
 				      kz_io_signals[IO_COMPLETED_SIGNAL],
 				      0, NULL);
@@ -487,9 +495,14 @@ cb_io_in(GIOChannel *iochannel, GIOCondition condition,
 		}
 	 case G_IO_STATUS_AGAIN :
 		{
-			g_signal_emit(io,
-				      kz_io_signals[IO_COMPLETED_SIGNAL],
-				      0, NULL);
+			if(priv->localfile)
+			{
+				g_io_channel_flush(priv->localfileio, NULL);
+				g_io_channel_unref(priv->localfileio);
+				priv->localfileio = NULL;
+			}
+
+			kz_io_start(io);
 			return FALSE;
 		}
 	 default:
