@@ -579,7 +579,7 @@ prefs_font_create (void)
 			 2, 2);       /* padding x, y  */
 	gtk_widget_show(hbox);
 
-	label = gtk_label_new_with_mnemonic(_("_Propotional: "));
+	label = gtk_label_new_with_mnemonic(_("_Proportional: "));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
