@@ -147,12 +147,11 @@ gchar *
 create_filename_from_uri (const gchar *uri)
 {
 	gchar *filename;
-	gint len, i = 0;
+	gint i = 0;
 	
 	filename = g_strdup(uri);
-	len = strlen(filename);
 
-	while (filename[i] != '\0' && i < len)
+	while (filename[i] != '\0')
 	{
 		if (filename[i] == '/')
 			filename[i] = '_';
@@ -433,30 +432,27 @@ gchar *
 xml_get_attr (const gchar *buffer, const gchar *attr_name)
 {
 	gchar *pos1, *pos2;
-	gchar *string1, *string2;
+	gchar *string;
 	gchar *attr = NULL;
 	guint len;
 
 	pos1 = strchr(buffer, '>');
-	if (pos1)
-		string1 = g_strndup(buffer, pos1 - buffer);
-	else 
+	if (!pos1)
 		return NULL;
-	
-	string2 = g_strdup_printf("%s=\"", attr_name);
-	len = strlen(string2);
-	pos1 = strstr(string1, string2); 
+
+	string = g_strdup_printf("%s=\"", attr_name);
+	pos1 = g_strstr_len(buffer, pos1 - buffer, string); 
 	if (pos1)
 	{
-		pos2 = strchr(pos1 + len, '"'); 
+		len = strlen(string);
+		pos1 += len;
+		pos2 = strchr(pos1, '"'); 
 		if (pos2)
-			attr = g_strndup(pos1 + len, pos2 - pos1 -len); 
+			attr = g_strndup(pos1, pos2 - pos1); 
 	}
-	g_free(string1);
-	g_free(string2);
+	g_free(string);
 	
 	return attr;
-
 }
 
 
@@ -709,6 +705,14 @@ convert_image (const gchar *ps_file, const gchar *png_file)
 			   &argv,
 			   NULL);
 
+        /* Check whether ghostscript is installed or not */
+	if(g_find_program_in_path (argv[0]) == NULL)
+	{
+		g_warning("Can't find %s in your PATH.\n"
+			  "Currently kazehakase using gecko engine needs ghostscript to create thumbnails.\n", argv[0]);
+		return;
+	}
+
 	flags = G_SPAWN_SEARCH_PATH;
 	g_spawn_async_with_pipes(NULL,
 		      		 argv,
